pub struct NuisanceSnapshot {
pub environment_fingerprint: Option<String>,
pub toolchain_version: Option<String>,
pub dependency_set_hash: Option<String>,
pub scope_mismatch_markers: Vec<String>,
pub measurement_notes: Vec<String>,
pub selection_bias_markers: Vec<String>,
}Fields
environment_fingerprint: Option<String>toolchain_version: Option<String>dependency_set_hash: Option<String>scope_mismatch_markers: Vec<String>measurement_notes: Vec<String>selection_bias_markers: Vec<String>Trait Implementations
Sourceimpl Clone for NuisanceSnapshot
impl Clone for NuisanceSnapshot
Sourcefn clone(&self) -> NuisanceSnapshot
fn clone(&self) -> NuisanceSnapshot
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NuisanceSnapshot
impl Debug for NuisanceSnapshot
Sourceimpl<'de> Deserialize<'de> for NuisanceSnapshot
impl<'de> Deserialize<'de> for NuisanceSnapshot
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for NuisanceSnapshot
impl JsonSchema for NuisanceSnapshot
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for NuisanceSnapshot
impl PartialEq for NuisanceSnapshot
Sourcefn eq(&self, other: &NuisanceSnapshot) -> bool
fn eq(&self, other: &NuisanceSnapshot) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for NuisanceSnapshot
impl Serialize for NuisanceSnapshot
impl Eq for NuisanceSnapshot
impl StructuralPartialEq for NuisanceSnapshot