pub struct ForgeToolBudgetContext {
pub budget_kind: Option<String>,
pub max_steps: Option<u32>,
pub time_budget_ms: Option<u64>,
pub cost_budget_units: Option<u64>,
}Fields
budget_kind: Option<String>max_steps: Option<u32>time_budget_ms: Option<u64>cost_budget_units: Option<u64>Trait Implementations
Sourceimpl Clone for ForgeToolBudgetContext
impl Clone for ForgeToolBudgetContext
Sourcefn clone(&self) -> ForgeToolBudgetContext
fn clone(&self) -> ForgeToolBudgetContext
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ForgeToolBudgetContext
impl Debug for ForgeToolBudgetContext
Sourceimpl<'de> Deserialize<'de> for ForgeToolBudgetContext
impl<'de> Deserialize<'de> for ForgeToolBudgetContext
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ForgeToolBudgetContext
impl JsonSchema for ForgeToolBudgetContext
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ForgeToolBudgetContext
impl RefUnwindSafe for ForgeToolBudgetContext
impl Send for ForgeToolBudgetContext
impl Sync for ForgeToolBudgetContext
impl Unpin for ForgeToolBudgetContext
impl UnsafeUnpin for ForgeToolBudgetContext
impl UnwindSafe for ForgeToolBudgetContext