pub struct ForgeToolReceiptV1 {Show 21 fields
pub schema_version: String,
pub receipt_id: String,
pub tool_run_id: String,
pub tool_name: String,
pub tool_version: String,
pub backend_kind: String,
pub input_digest: ContentDigest,
pub output_digest_or_refs: Value,
pub policy_hash: ContentDigest,
pub approval_state: String,
pub host_identity: String,
pub started_at: String,
pub finished_at: String,
pub trace_ctx: TraceCtx,
pub attempt_id: AttemptId,
pub trial_id: TrialId,
pub error_class: Option<String>,
pub retry_owner: String,
pub replay_link: Option<String>,
pub provider_call_id: Option<String>,
pub raw_payload: Value,
}Fields
schema_version: Stringreceipt_id: Stringtool_run_id: Stringtool_name: Stringtool_version: Stringbackend_kind: Stringinput_digest: ContentDigestoutput_digest_or_refs: Valuepolicy_hash: ContentDigestapproval_state: Stringhost_identity: Stringstarted_at: Stringfinished_at: Stringtrace_ctx: TraceCtxattempt_id: AttemptIdtrial_id: TrialIderror_class: Option<String>retry_owner: Stringreplay_link: Option<String>provider_call_id: Option<String>raw_payload: ValueTrait Implementations
Sourceimpl Clone for ForgeToolReceiptV1
impl Clone for ForgeToolReceiptV1
Sourcefn clone(&self) -> ForgeToolReceiptV1
fn clone(&self) -> ForgeToolReceiptV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ForgeToolReceiptV1
impl Debug for ForgeToolReceiptV1
Sourceimpl<'de> Deserialize<'de> for ForgeToolReceiptV1
impl<'de> Deserialize<'de> for ForgeToolReceiptV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ForgeToolReceiptV1
impl JsonSchema for ForgeToolReceiptV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ForgeToolReceiptV1
impl RefUnwindSafe for ForgeToolReceiptV1
impl Send for ForgeToolReceiptV1
impl Sync for ForgeToolReceiptV1
impl Unpin for ForgeToolReceiptV1
impl UnsafeUnpin for ForgeToolReceiptV1
impl UnwindSafe for ForgeToolReceiptV1