pub struct ExactnessEscalationRuleV1 {
pub when_degraded: DegradationKindV1,
pub escalate_to: ExactnessLevelV1,
pub block_action: Option<String>,
}Fields
when_degraded: DegradationKindV1escalate_to: ExactnessLevelV1block_action: Option<String>Trait Implementations
Sourceimpl Clone for ExactnessEscalationRuleV1
impl Clone for ExactnessEscalationRuleV1
Sourcefn clone(&self) -> ExactnessEscalationRuleV1
fn clone(&self) -> ExactnessEscalationRuleV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExactnessEscalationRuleV1
impl Debug for ExactnessEscalationRuleV1
Sourceimpl<'de> Deserialize<'de> for ExactnessEscalationRuleV1
impl<'de> Deserialize<'de> for ExactnessEscalationRuleV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExactnessEscalationRuleV1
impl JsonSchema for ExactnessEscalationRuleV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExactnessEscalationRuleV1
impl PartialEq for ExactnessEscalationRuleV1
Sourcefn eq(&self, other: &ExactnessEscalationRuleV1) -> bool
fn eq(&self, other: &ExactnessEscalationRuleV1) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ExactnessEscalationRuleV1
impl StructuralPartialEq for ExactnessEscalationRuleV1