pub struct QualityVectorV1 {
pub exactness: ExactnessLevelV1,
pub degradation: Vec<DegradationKindV1>,
pub freshness: Option<String>,
pub replay_limited: bool,
pub execution_contaminated: bool,
}Fields
exactness: ExactnessLevelV1degradation: Vec<DegradationKindV1>freshness: Option<String>replay_limited: boolexecution_contaminated: boolTrait Implementations
Sourceimpl Clone for QualityVectorV1
impl Clone for QualityVectorV1
Sourcefn clone(&self) -> QualityVectorV1
fn clone(&self) -> QualityVectorV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for QualityVectorV1
impl Debug for QualityVectorV1
Sourceimpl<'de> Deserialize<'de> for QualityVectorV1
impl<'de> Deserialize<'de> for QualityVectorV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for QualityVectorV1
impl JsonSchema for QualityVectorV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for QualityVectorV1
impl PartialEq for QualityVectorV1
Sourcefn eq(&self, other: &QualityVectorV1) -> bool
fn eq(&self, other: &QualityVectorV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for QualityVectorV1
impl Serialize for QualityVectorV1
impl Eq for QualityVectorV1
impl StructuralPartialEq for QualityVectorV1