pub struct SupportTokenV1 {
pub token_id: String,
pub kind: SupportProvenanceKindV1,
pub reference: String,
pub polarity: SupportPolarityV1,
}Fields
token_id: Stringkind: SupportProvenanceKindV1reference: Stringpolarity: SupportPolarityV1Trait Implementations
Sourceimpl Clone for SupportTokenV1
impl Clone for SupportTokenV1
Sourcefn clone(&self) -> SupportTokenV1
fn clone(&self) -> SupportTokenV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SupportTokenV1
impl Debug for SupportTokenV1
Sourceimpl<'de> Deserialize<'de> for SupportTokenV1
impl<'de> Deserialize<'de> for SupportTokenV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SupportTokenV1
impl JsonSchema for SupportTokenV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SupportTokenV1
impl PartialEq for SupportTokenV1
Sourcefn eq(&self, other: &SupportTokenV1) -> bool
fn eq(&self, other: &SupportTokenV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SupportTokenV1
impl Serialize for SupportTokenV1
impl Eq for SupportTokenV1
impl StructuralPartialEq for SupportTokenV1