pub struct CohortContractV1 {
pub schema_version: String,
pub cohort_contract_id: CohortContractId,
pub unit_definition: String,
pub inclusion_logic: Vec<String>,
pub exclusion_logic: Vec<String>,
pub scope_namespace: String,
pub workload_class: String,
pub environment_constraints: Vec<String>,
pub replay_linkage: String,
}Fields
schema_version: Stringcohort_contract_id: CohortContractIdunit_definition: Stringinclusion_logic: Vec<String>exclusion_logic: Vec<String>scope_namespace: Stringworkload_class: Stringenvironment_constraints: Vec<String>replay_linkage: StringTrait Implementations
Sourceimpl Clone for CohortContractV1
impl Clone for CohortContractV1
Sourcefn clone(&self) -> CohortContractV1
fn clone(&self) -> CohortContractV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CohortContractV1
impl Debug for CohortContractV1
Sourceimpl<'de> Deserialize<'de> for CohortContractV1
impl<'de> Deserialize<'de> for CohortContractV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CohortContractV1
impl JsonSchema for CohortContractV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CohortContractV1
impl PartialEq for CohortContractV1
Sourcefn eq(&self, other: &CohortContractV1) -> bool
fn eq(&self, other: &CohortContractV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CohortContractV1
impl Serialize for CohortContractV1
impl Eq for CohortContractV1
impl StructuralPartialEq for CohortContractV1