pub struct CounterfactualSliceV1 {
pub schema_version: String,
pub counterfactual_slice_id: CounterfactualSliceId,
pub intervention_id: InterventionId,
pub baseline_treatment: String,
pub cohort_contract_id: CohortContractId,
pub as_of_valid_time: String,
pub as_of_recorded_time: String,
pub replayable_data_slice: String,
pub exactness_target: String,
pub modeling_assumptions: Vec<String>,
pub expected_failure_modes: Vec<String>,
}Fields
schema_version: Stringcounterfactual_slice_id: CounterfactualSliceIdintervention_id: InterventionIdbaseline_treatment: Stringcohort_contract_id: CohortContractIdas_of_valid_time: Stringas_of_recorded_time: Stringreplayable_data_slice: Stringexactness_target: Stringmodeling_assumptions: Vec<String>expected_failure_modes: Vec<String>Trait Implementations
Sourceimpl Clone for CounterfactualSliceV1
impl Clone for CounterfactualSliceV1
Sourcefn clone(&self) -> CounterfactualSliceV1
fn clone(&self) -> CounterfactualSliceV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CounterfactualSliceV1
impl Debug for CounterfactualSliceV1
Sourceimpl<'de> Deserialize<'de> for CounterfactualSliceV1
impl<'de> Deserialize<'de> for CounterfactualSliceV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CounterfactualSliceV1
impl JsonSchema for CounterfactualSliceV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CounterfactualSliceV1
impl PartialEq for CounterfactualSliceV1
Sourcefn eq(&self, other: &CounterfactualSliceV1) -> bool
fn eq(&self, other: &CounterfactualSliceV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CounterfactualSliceV1
impl Serialize for CounterfactualSliceV1
impl Eq for CounterfactualSliceV1
impl StructuralPartialEq for CounterfactualSliceV1