pub struct InterventionBundleV1 {Show 15 fields
pub schema_version: String,
pub intervention_id: InterventionId,
pub episode_id: EpisodeId,
pub unit_of_analysis: String,
pub treatment_definition: String,
pub baseline_treatment: String,
pub start_condition: String,
pub stop_condition: String,
pub allowed_scope: Option<ScopeKey>,
pub valid_from: String,
pub valid_to: Option<String>,
pub recorded_at: String,
pub related_claim_ids: Vec<ClaimId>,
pub policy_refs: Vec<String>,
pub approval_refs: Vec<String>,
}Fields
schema_version: Stringintervention_id: InterventionIdepisode_id: EpisodeIdunit_of_analysis: Stringtreatment_definition: Stringbaseline_treatment: Stringstart_condition: Stringstop_condition: Stringallowed_scope: Option<ScopeKey>valid_from: Stringvalid_to: Option<String>recorded_at: Stringpolicy_refs: Vec<String>approval_refs: Vec<String>Trait Implementations
Sourceimpl Clone for InterventionBundleV1
impl Clone for InterventionBundleV1
Sourcefn clone(&self) -> InterventionBundleV1
fn clone(&self) -> InterventionBundleV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InterventionBundleV1
impl Debug for InterventionBundleV1
Sourceimpl<'de> Deserialize<'de> for InterventionBundleV1
impl<'de> Deserialize<'de> for InterventionBundleV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for InterventionBundleV1
impl JsonSchema for InterventionBundleV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for InterventionBundleV1
impl PartialEq for InterventionBundleV1
Sourcefn eq(&self, other: &InterventionBundleV1) -> bool
fn eq(&self, other: &InterventionBundleV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for InterventionBundleV1
impl Serialize for InterventionBundleV1
impl Eq for InterventionBundleV1
impl StructuralPartialEq for InterventionBundleV1