pub struct OutcomeSchemaV1 {
pub schema_version: String,
pub outcome_schema_id: OutcomeSchemaId,
pub name: String,
pub measurement_definition: String,
pub time_window: String,
pub aggregation_rule: String,
pub degradation_behavior: String,
pub exactness_requirement: String,
}Fields
schema_version: Stringoutcome_schema_id: OutcomeSchemaIdname: Stringmeasurement_definition: Stringtime_window: Stringaggregation_rule: Stringdegradation_behavior: Stringexactness_requirement: StringTrait Implementations
Sourceimpl Clone for OutcomeSchemaV1
impl Clone for OutcomeSchemaV1
Sourcefn clone(&self) -> OutcomeSchemaV1
fn clone(&self) -> OutcomeSchemaV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OutcomeSchemaV1
impl Debug for OutcomeSchemaV1
Sourceimpl<'de> Deserialize<'de> for OutcomeSchemaV1
impl<'de> Deserialize<'de> for OutcomeSchemaV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OutcomeSchemaV1
impl JsonSchema for OutcomeSchemaV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for OutcomeSchemaV1
impl PartialEq for OutcomeSchemaV1
Sourcefn eq(&self, other: &OutcomeSchemaV1) -> bool
fn eq(&self, other: &OutcomeSchemaV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for OutcomeSchemaV1
impl Serialize for OutcomeSchemaV1
impl Eq for OutcomeSchemaV1
impl StructuralPartialEq for OutcomeSchemaV1