pub struct EpisodeBundleV1 {Show 23 fields
pub schema_version: String,
pub bundle_id: String,
pub episode_id: EpisodeId,
pub primary_document_id: String,
pub namespace: String,
pub scope_key: ScopeKey,
pub valid_from: Option<String>,
pub valid_to: Option<String>,
pub exported_at: String,
pub recorded_at: Option<String>,
pub source_envelope_id: EnvelopeId,
pub content_digest: ContentDigest,
pub source_evidence_pointers: Vec<String>,
pub source_receipt_digests: Vec<String>,
pub claim_version_ids: Vec<String>,
pub relation_version_ids: Vec<String>,
pub verification_summary: Option<VerificationSummary>,
pub refutation_artifact_ids: Vec<String>,
pub control_plane_refs: Vec<String>,
pub execution_context: ExecutionContextV1,
pub thin_export: bool,
pub supersedes_bundle_id: Option<String>,
pub evidence_bundle_id: Option<String>,
}Fields
schema_version: Stringbundle_id: Stringepisode_id: EpisodeIdprimary_document_id: Stringnamespace: Stringscope_key: ScopeKeyvalid_from: Option<String>valid_to: Option<String>exported_at: Stringrecorded_at: Option<String>source_envelope_id: EnvelopeIdcontent_digest: ContentDigestsource_evidence_pointers: Vec<String>source_receipt_digests: Vec<String>claim_version_ids: Vec<String>relation_version_ids: Vec<String>verification_summary: Option<VerificationSummary>refutation_artifact_ids: Vec<String>control_plane_refs: Vec<String>execution_context: ExecutionContextV1thin_export: boolsupersedes_bundle_id: Option<String>evidence_bundle_id: Option<String>Trait Implementations
Sourceimpl Clone for EpisodeBundleV1
impl Clone for EpisodeBundleV1
Sourcefn clone(&self) -> EpisodeBundleV1
fn clone(&self) -> EpisodeBundleV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EpisodeBundleV1
impl Debug for EpisodeBundleV1
Sourceimpl<'de> Deserialize<'de> for EpisodeBundleV1
impl<'de> Deserialize<'de> for EpisodeBundleV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EpisodeBundleV1
impl JsonSchema for EpisodeBundleV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EpisodeBundleV1
impl PartialEq for EpisodeBundleV1
Sourcefn eq(&self, other: &EpisodeBundleV1) -> bool
fn eq(&self, other: &EpisodeBundleV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for EpisodeBundleV1
impl Serialize for EpisodeBundleV1
impl Eq for EpisodeBundleV1
impl StructuralPartialEq for EpisodeBundleV1