pub struct ExecutionContextV1 {Show 17 fields
pub schema_version: String,
pub trace_ctx: TraceCtx,
pub attempt_id: Option<AttemptId>,
pub trial_id: Option<TrialId>,
pub replay_link: Option<String>,
pub workload_class: Option<String>,
pub queue_hops: Vec<String>,
pub deadline: Option<String>,
pub cost_budget_units: Option<u64>,
pub degradation_markers: Vec<String>,
pub dispatch_outcome: DispatchOutcomeV1,
pub environment_fingerprint: Option<String>,
pub provider_route: Option<String>,
pub cancellation_reason: Option<String>,
pub tool_receipt_ref: Option<String>,
pub provider_call_ref: Option<String>,
pub replay_parent_ref: Option<String>,
}Fields
schema_version: Stringtrace_ctx: TraceCtxattempt_id: Option<AttemptId>trial_id: Option<TrialId>replay_link: Option<String>workload_class: Option<String>queue_hops: Vec<String>deadline: Option<String>cost_budget_units: Option<u64>degradation_markers: Vec<String>dispatch_outcome: DispatchOutcomeV1environment_fingerprint: Option<String>provider_route: Option<String>cancellation_reason: Option<String>tool_receipt_ref: Option<String>Backpointer to the tool receipt that produced this execution context.
provider_call_ref: Option<String>Backpointer to the provider call that fulfilled this execution.
replay_parent_ref: Option<String>Backpointer to the replay parent execution context, if this is a retry.
Implementations